@@ -1,4 +1,4 @@
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 from django.utils.safestring import mark_safe
 from django.forms import widgets
 from django.conf import settings
@@ -48,7 +48,7 @@ class RelatedFieldWidgetCanAdd(widgets.Select):
                 name,
                 value,
                 *args,
-                **kwargs
+                **kwargs,
             )
         ]
         output.append('<a href="%s" class="add-another" id="add_id_%s" onclick="return showAddAnotherPopup(this);"> ' % \
